@@ -11,5 +11,6 @@
 #' 
 #' @export
 #' @references .
-buildModelClass <- function(x, var.names, init.cond, model.parms, prop.func = NULL,
-                            state.var = NULL, state.change.matrix = NULL) UseMethod("buildModelClass")
\ No newline at end of file
+buildModelClass <- function(x, var.names, init.cond, model.parms,
+                            prop.func = NULL, state.var = NULL, infl.var = NULL,
+                            state.change.matrix = NULL) UseMethod("buildModelClass")
\ No newline at end of file
